@@ -66,7 +66,7 @@ def override(name, value):
 
 def load(dependencies, override=False):
     s = schema.Parser(override=override).load(dependencies)
-    s.resolve(schema.Resolver())
+    s.resolve(schema.Resolver(provider))
 
 
 def load_config(
